@@ -1,6 +1,6 @@
 ETH_CHAIN = 'ETHERIUM'
 POLYGON_CHAIN = 'POLYGON'
-SOLNANA_CHAIN = 'SOLANA'
+SOLANA_CHAIN = 'SOLANA'
 
 ETHNET = "https://api.etherscan.io"
 POLYGONNET = "https://api.polygonscan.com"
